# Connecting fast.ai with RawPy
Here we can make fast.ai framework support RawPy library, hence use RAW image files on fastai

# How to install
Use:

```pip install fastai-rawpy```

to install this package that lets you use fast.ai and RAW image files as well.

# How to import fastai-rawpy

Use:

```from fastairawpy import *```

in order to import `RawImageBlock` as well as all of the necessary functions/classes/etc that adjust fast.ai so it supports RawPy.

While using fast.ai, wherever you could have used `ImageBlock`, just type in `RawImageBlock`.